@@ -32,7 +32,7 @@
 # Version
 # -------
 #
-# * ltfatpy version = 1.0.12
+# * ltfatpy version = 1.0.16
 # * LTFAT version = 2.1.0
 #
 # Licence
@@ -104,8 +104,8 @@ def assert_sigreshape_pre(f, L=None, dim=None):
         f = np.asarray(f)
 
 # ----Check that f type is numeric
-    if (not np.issubdtype(f.dtype, np.float) and
-       not np.issubdtype(f.dtype, np.complex) and
+    if (not np.issubdtype(f.dtype, np.floating) and
+       not np.issubdtype(f.dtype, np.complexfloating) and
        not np.issubdtype(f.dtype, np.integer)):
         raise TypeError("f data type should be numeric.")
     D = f.ndim
