@@ -32,7 +32,7 @@
 # Version
 # -------
 #
-# * ltfatpy version = 1.0.12
+# * ltfatpy version = 1.0.16
 # * LTFAT version = 2.1.0
 #
 # Licence
@@ -75,8 +75,8 @@ def comp_sigreshape_pre(f, do_ndim):
     """
     if not isinstance(f, np.ndarray):
         raise ValueError("f should be a numpy array.")
-    elif f.size == 0 or (not np.issubdtype(f.dtype, np.float) and
-                         not np.issubdtype(f.dtype, np.complex) and
+    elif f.size == 0 or (not np.issubdtype(f.dtype, np.floating) and
+                         not np.issubdtype(f.dtype, np.complexfloating) and
                          not np.issubdtype(f.dtype, np.integer)):
         raise ValueError('The input must be non-empty numeric.')
 
