@@ -32,7 +32,7 @@
 # Version
 # -------
 #
-# * ltfatpy version = 1.0.12
+# * ltfatpy version = 1.0.16
 # * LTFAT version = 2.1.0
 #
 # Licence
@@ -247,7 +247,7 @@ def comp_window(g, a, M, L=None):
             g = fir2long(g, int(np.ceil(g.shape[0] / M) * M))
 
         # Information to be determined post creation.
-        info['wasreal'] = np.issubdtype(g.dtype, np.float)
+        info['wasreal'] = np.issubdtype(g.dtype, np.floating)
         info['gl'] = g.shape[0]
         if L is not None and info['gl'] < L:
             info['isfir'] = True
