@@ -32,7 +32,7 @@
 # Version
 # -------
 #
-# * ltfatpy version = 1.0.12
+# * ltfatpy version = 1.0.16
 # * LTFAT version = 2.1.0
 #
 # Licence
@@ -178,7 +178,7 @@ def dgtreal(f, g, a, M, L=None, pt='freqinv'):
     """
     (f, gnum, _, Ls) = gabpars_from_windowsignal(f, g, a, M, L)[0:4]
 
-    if not np.issubdtype(gnum.dtype, np.float):
+    if not np.issubdtype(gnum.dtype, np.floating):
         raise ValueError('The window must be real-valued.')
 
     # verify pt
