@@ -32,7 +32,7 @@
 # Version
 # -------
 #
-# * ltfatpy version = 1.0.12
+# * ltfatpy version = 1.0.16
 # * LTFAT version = 2.1.0
 #
 # Licence
@@ -191,7 +191,7 @@ def gabtight(g, a, M, L=None):
         gt = comp_gabtight_long(g, a, M) * scale
 
     # post process result
-    if np.issubdtype(g.dtype, np.float):
+    if np.issubdtype(g.dtype, np.floating):
         # If g is real then the output is known to be real.
         gt = gt.real
 
