@@ -32,7 +32,7 @@
 # Version
 # -------
 #
-# * ltfatpy version = 1.0.12
+# * ltfatpy version = 1.0.16
 # * LTFAT version = 2.1.0
 #
 # Licence
@@ -204,7 +204,7 @@ def idgtreal(coef, g, a, M, Ls=None, pt='freqinv'):
     if L < info['gl']:
         raise ValueError('Window is too long.')
 
-    if not np.issubdtype(g.dtype, np.float):
+    if not np.issubdtype(g.dtype, np.floating):
         raise ValueError('The window must be real-valued.')
 
     # verify pt
