@@ -32,7 +32,7 @@
 # Version
 # -------
 #
-# * ltfatpy version = 1.0.12
+# * ltfatpy version = 1.0.16
 # * LTFAT version = 2.1.0
 #
 # Licence
@@ -195,7 +195,7 @@ def tfplot(coef, step, yr, fs=None, dynrange=None, normalization='db',
     # 'dynrange' parameter is handled by converting it into clim
     #  clim overrides dynrange, so do nothing if clim is already specified
     if dynrange and not clim:
-        maxclim = np.max(coef)
+        maxclim = np.nanmax(coef)
         clim = (maxclim - dynrange, maxclim)
 
     # Handle clim by thresholding and cutting
@@ -245,7 +245,8 @@ def tfplot(coef, step, yr, fs=None, dynrange=None, normalization='db',
             # plot_surface
             from mpl_toolkits.mplot3d import Axes3D
 
-            ax = plt.gca(projection='3d')
+            plt.delaxes()
+            ax = plt.gcf().add_subplot(111, projection='3d')
             ax.azim = -130.
             ax.elev = 30.
             xgrid, ygrid = np.meshgrid(xr, yr)
