@@ -32,7 +32,7 @@
 # Version
 # -------
 #
-# * ltfatpy version = 1.0.12
+# * ltfatpy version = 1.0.16
 # * LTFAT version = 2.1.0
 #
 # Licence
@@ -151,7 +151,7 @@ def normalize(f, norm='2', dim=None):
             fnorm[ii] = s0norm(f[:, ii])
             f[:, ii] = f[:, ii] / fnorm[ii]
         elif norm == 'wav':
-            if np.issubdtype(f.dtype, np.float):
+            if np.issubdtype(f.dtype, np.floating):
                 fnorm[ii] = LA.norm(f[:, ii], np.inf)
                 f[:, ii] = 0.99 * f[:, ii] / fnorm[ii]
             else:
