@@ -32,7 +32,7 @@
 # Version
 # -------
 #
-# * ltfatpy version = 1.0.12
+# * ltfatpy version = 1.0.16
 # * LTFAT version = 2.1.0
 #
 # Licence
@@ -80,12 +80,16 @@ class TestCompGabDual(unittest.TestCase):
         # g should be float64 or complex128
         g = np.arange(9)
         mess = "g data should be numpy.float64 or numpy.complex128"
-        self.assertRaisesRegexp(TypeError, mess, comp_gabdual_long, g, 0, 0)
+        try:
+            assertRaisesRegex = self.assertRaisesRegex
+        except AttributeError:
+            assertRaisesRegex = self.assertRaisesRegexp
+        assertRaisesRegex(TypeError, mess, comp_gabdual_long, g, 0, 0)
         g = g.astype(np.float64)
         # g dim should be < 3
         mess = "g dimensions should be 1 or 2."
-        self.assertRaisesRegexp(TypeError, mess, comp_gabdual_long,
-                                g.reshape((3, 1, 3)), 0, 0)
+        assertRaisesRegex(
+            TypeError, mess, comp_gabdual_long, g.reshape((3, 1, 3)), 0, 0)
         # basic test:
         g.resize((3, 3))
         gd = comp_gabdual_long(g, 1, 1)
