@@ -32,7 +32,7 @@
 # Version
 # -------
 #
-# * ltfatpy version = 1.0.12
+# * ltfatpy version = 1.0.16
 # * LTFAT version = 2.1.0
 #
 # Licence
@@ -62,9 +62,16 @@
 from __future__ import print_function, division
 
 import unittest
-from ltfatpy.tests.datasets.read_dgt_signal_ex_mat import DgtSignals
 import numpy
-import fractions
+try:
+    from math import gcd
+except ImportError:
+    # fractions.gcd() is deprecated since Python 3.5 and math.gcd() should be
+    # used instead, but for backward compatibilty we use fractions.gcd() if
+    # math.gcd() is not available
+    from fractions import gcd
+
+from ltfatpy.tests.datasets.read_dgt_signal_ex_mat import DgtSignals
 from ltfatpy.tests.datasets.get_dataset_path import get_dataset_path
 
 
@@ -107,7 +114,7 @@ class TestReadDgtSignalExt(unittest.TestCase):
             if (gl == M):
                 assert DUAL_WINDOW.size == gl
             elif (a != M):
-                assert DUAL_WINDOW.size == a * M // fractions.gcd(a, M)
+                assert DUAL_WINDOW.size == a * M // gcd(a, M)
             else:
                 assert DUAL_WINDOW.size == a * 2
 
