@@ -32,7 +32,7 @@
 # Version
 # -------
 #
-# * ltfatpy version = 1.0.12
+# * ltfatpy version = 1.0.16
 # * LTFAT version = 2.1.0
 #
 # Licence
@@ -89,8 +89,8 @@ class TestPsech(unittest.TestCase):
         mess += "psech(10.2)\n"
         self.assertRaises(TypeError, psech, 10.2, mess)
         mess = "\nException TypeError should be raised with declaration "
-        mess += "psech(10,(1,1))\n"
-        self.assertRaises(TypeError, psech, 10, (1, 1))
+        mess += "psech(10, s=(1,1))\n"
+        self.assertRaises(TypeError, psech, 10, s=(1, 1))
 
     def test_invariance_property(self):
         g = psech(self.L)[0]
