@@ -32,7 +32,7 @@
 # Version
 # -------
 #
-# * ltfatpy version = 1.0.12
+# * ltfatpy version = 1.0.16
 # * LTFAT version = 2.1.0
 #
 # Licence
@@ -106,8 +106,8 @@ class TestGabWin(unittest.TestCase):
         self.assertFalse(info['isdual'], mess)
         self.assertFalse(info['wasrow'], mess)
         self.assertFalse(info['isfir'], mess)
-        self.assertEquals(info["tfr"], a*M/L, mess)
-        self.assertEquals(info["gl"], len(g), mess)
+        self.assertEqual(info["tfr"], a*M/L, mess)
+        self.assertEqual(info["gl"], len(g), mess)
         gt = pgauss(L, a*M/L)[0]
         mess += "\ngt = " + str(gt)
         np.testing.assert_array_almost_equal(g, gt, 10, mess)
@@ -128,8 +128,8 @@ class TestGabWin(unittest.TestCase):
         self.assertFalse(info['isdual'], mess)
         self.assertFalse(info['wasrow'], mess)
         self.assertFalse(info['isfir'], mess)
-        self.assertEquals(info["tfr"], a*M/L, mess)
-        self.assertEquals(info["gl"], len(g), mess)
+        self.assertEqual(info["tfr"], a*M/L, mess)
+        self.assertEqual(info["gl"], len(g), mess)
         gt = psech(L, a*M/L)[0]
         mess += "\ngt = " + str(gt)
         np.testing.assert_array_almost_equal(g, gt, 10, mess)
@@ -146,8 +146,8 @@ class TestGabWin(unittest.TestCase):
         self.assertTrue(info['isdual'], mess)
         self.assertFalse(info['wasrow'], mess)
         self.assertFalse(info['isfir'], mess)
-        self.assertEquals(info["tfr"], a*M/L, mess)
-        self.assertEquals(info["gl"], len(g), mess)
+        self.assertEqual(info["tfr"], a*M/L, mess)
+        self.assertEqual(info["gl"], len(g), mess)
         gt = gabdual(pgauss(L, a*M/L)[0], a, M)
         mess += "\ngt = " + str(gt)
         np.testing.assert_array_almost_equal(g, gt, 10, mess)
@@ -165,8 +165,8 @@ class TestGabWin(unittest.TestCase):
         self.assertFalse(info['isdual'], mess)
         self.assertFalse(info['wasrow'], mess)
         self.assertFalse(info['isfir'], mess)
-        self.assertEquals(info["tfr"], a*M/L, mess)
-        self.assertEquals(info["gl"], len(g), mess)
+        self.assertEqual(info["tfr"], a*M/L, mess)
+        self.assertEqual(info["gl"], len(g), mess)
         gt = gabtight(None, a, M, L)
         mess += "\ngt = " + str(gt)
         np.testing.assert_array_almost_equal(g, gt, 10, mess)
@@ -189,7 +189,7 @@ class TestGabWin(unittest.TestCase):
         self.assertFalse(info['isdual'], mess)
         self.assertFalse(info['wasrow'], mess)
         self.assertTrue(info['isfir'], mess)
-        self.assertEquals(info["gl"], len(g), mess)
+        self.assertEqual(info["gl"], len(g), mess)
         gt = firwin(name, M, norm='2')[0]
         mess += "\ngt = " + str(gt)
         np.testing.assert_array_almost_equal(g, gt, 10, mess)
@@ -216,8 +216,8 @@ class TestGabWin(unittest.TestCase):
         self.assertFalse(info['isdual'], mess)
         self.assertFalse(info['wasrow'], mess)
         self.assertFalse(info['isfir'], mess)
-        self.assertEquals(info["tfr"], a*M/L, mess)
-        self.assertEquals(info["gl"], len(g), mess)
+        self.assertEqual(info["tfr"], a*M/L, mess)
+        self.assertEqual(info["gl"], len(g), mess)
         gt = pgauss(L, a*M/L)[0]
         mess += "\ngt = " + str(gt)
         np.testing.assert_array_almost_equal(g, gt, 10, mess)
@@ -227,7 +227,7 @@ class TestGabWin(unittest.TestCase):
         mess = "a = {0:d}, M = {1:d}, L = {2:d}".format(a, M, L)
         mess += "\ng = " + str(g)
         mess += "\ninfo = " + str(info)
-        self.assertEquals(info["tfr"], 1, mess)
+        self.assertEqual(info["tfr"], 1, mess)
         gt = pgauss(L)[0]
         mess += "\ngt = " + str(gt)
         np.testing.assert_array_almost_equal(g, gt, 10, mess)
@@ -243,8 +243,8 @@ class TestGabWin(unittest.TestCase):
         self.assertFalse(info['isdual'], mess)
         self.assertFalse(info['wasrow'], mess)
         self.assertFalse(info['isfir'], mess)
-        self.assertEquals(info["tfr"], a*M/L, mess)
-        self.assertEquals(info["gl"], len(g), mess)
+        self.assertEqual(info["tfr"], a*M/L, mess)
+        self.assertEqual(info["gl"], len(g), mess)
         gt = psech(L, a*M/L)[0]
         mess += "\ngt = " + str(gt)
         np.testing.assert_array_almost_equal(g, gt, 10, mess)
@@ -254,7 +254,7 @@ class TestGabWin(unittest.TestCase):
         mess = "a = {0:d}, M = {1:d}, L = {2:d}".format(a, M, L)
         mess += "\ng = " + str(g)
         mess += "\ninfo = " + str(info)
-        self.assertEquals(info["tfr"], 1, mess)
+        self.assertEqual(info["tfr"], 1, mess)
         gt = psech(L)[0]
         mess += "\ngt = " + str(gt)
         np.testing.assert_array_almost_equal(g, gt, 10, mess)
@@ -293,7 +293,7 @@ class TestGabWin(unittest.TestCase):
         self.assertFalse(info['isdual'], mess)
         self.assertFalse(info['wasrow'], mess)
         self.assertTrue(info['isfir'], mess)
-        self.assertEquals(info["gl"], len(gl), mess)
+        self.assertEqual(info["gl"], len(gl), mess)
         gt = firwin(name, Ml, norm='2')[0]
         gt = fir2long(gt, int(np.ceil(gt.shape[0] / M) * M))
         mess += "\ngt = " + str(gt)
@@ -324,8 +324,8 @@ class TestGabWin(unittest.TestCase):
         self.assertTrue(info['isdual'], mess)
         self.assertFalse(info['wasrow'], mess)
         self.assertFalse(info['isfir'], mess)
-        self.assertEquals(info['auxinfo']["tfr"], tfr, mess)
-        self.assertEquals(info["gl"], len(g), mess)
+        self.assertEqual(info['auxinfo']["tfr"], tfr, mess)
+        self.assertEqual(info["gl"], len(g), mess)
         gt = gabdual(psech(L, tfr)[0], a, M, L)
         mess += "\ngt = " + str(gt)
         np.testing.assert_array_almost_equal(g, gt, 10, mess)
@@ -345,8 +345,8 @@ class TestGabWin(unittest.TestCase):
         self.assertTrue(info['isdual'], mess)
         self.assertFalse(info['wasrow'], mess)
         self.assertFalse(info['isfir'], mess)
-        self.assertEquals(info['auxinfo']["tfr"], tfr, mess)
-        self.assertEquals(info["gl"], len(g), mess)
+        self.assertEqual(info['auxinfo']["tfr"], tfr, mess)
+        self.assertEqual(info["gl"], len(g), mess)
         gt = gabdual(pgauss(L, tfr)[0], a, M, L)
         mess += "\ngt = " + str(gt)
         np.testing.assert_array_almost_equal(g, gt, 10, mess)
@@ -365,7 +365,7 @@ class TestGabWin(unittest.TestCase):
         self.assertTrue(info['isdual'], mess)
         self.assertFalse(info['wasrow'], mess)
         self.assertTrue(info['isfir'], mess)
-        self.assertEquals(info["gl"], len(g), mess)
+        self.assertEqual(info["gl"], len(g), mess)
         gt = firwin(name, M, norm='2')[0]
         gt = gabdual(gt, a, M, L)
         mess += "\ngt = " + str(gt)
@@ -384,7 +384,7 @@ class TestGabWin(unittest.TestCase):
         self.assertFalse(info['isdual'], mess)
         self.assertFalse(info['wasrow'], mess)
         self.assertTrue(info['isfir'], mess)
-        self.assertEquals(info["gl"], len(g), mess)
+        self.assertEqual(info["gl"], len(g), mess)
         gt = firwin(name, M, norm='2')[0]
         gt = gabtight(gt, a, M, L)
         mess += "\ngt = " + str(gt)
@@ -403,7 +403,7 @@ class TestGabWin(unittest.TestCase):
         self.assertFalse(info['isdual'], mess)
         self.assertTrue(info['wasrow'], mess)
         self.assertFalse(info['isfir'], mess)
-        self.assertEquals(info["gl"], L, mess)
+        self.assertEqual(info["gl"], L, mess)
         gt = pgauss(L)[0]
         mess += "\ngt = " + str(gt)
         np.testing.assert_array_almost_equal(g, gt, 10, mess)
