@@ -32,7 +32,7 @@
 # Version
 # -------
 #
-# * ltfatpy version = 1.0.12
+# * ltfatpy version = 1.0.16
 # * LTFAT version = 2.1.0
 #
 # Licence
@@ -63,7 +63,7 @@ from __future__ import print_function, division
 
 import unittest
 import numpy as np
-from numpy.testing import assert_array_equal, assert_allclose
+from numpy.testing import assert_allclose
 
 from ltfatpy.gabor.phaselock import phaselock
 from ltfatpy.gabor.phaseunlock import phaseunlock
@@ -107,7 +107,7 @@ class TestPhaselock(unittest.TestCase):
             out = phaselock(**inputs)
             msg = ('Wrong output in phaselock with inputs ' +
                    str(inputs))
-            assert_array_equal(out, outputs[0], msg)
+            assert_allclose(out, outputs[0], rtol=1e-15, err_msg=msg)
 
     def test_inverse(self):
         """Check that phaselock and phaseunlock are inverse functions
