@@ -32,7 +32,7 @@
 # Version
 # -------
 #
-# * ltfatpy version = 1.0.12
+# * ltfatpy version = 1.0.16
 # * LTFAT version = 2.1.0
 #
 # Licence
@@ -63,7 +63,7 @@ from __future__ import print_function, division
 
 import unittest
 import numpy as np
-from numpy.testing import assert_array_equal
+from numpy.testing import assert_allclose
 
 from ltfatpy.gabor.phaseunlock import phaseunlock
 from ltfatpy.gabor.dgt import dgt
@@ -106,7 +106,7 @@ class TestPhaseunlock(unittest.TestCase):
             out = phaseunlock(**inputs)
             msg = ('Wrong output in phaseunlock with inputs ' +
                    str(inputs))
-            assert_array_equal(out, outputs[0], msg)
+            assert_allclose(out, outputs[0], rtol=1e-15, err_msg=msg)
 
 
 if __name__ == '__main__':
